@@ -57,26 +57,13 @@ Module Example:
 
     >>> import jc.parsers.dig
     >>>
-    >>> data = '''; <<>> DiG 9.10.6 <<>> example.com
-    ... ;; global options: +cmd
-    ... ;; Got answer:
-    ... ;; ->>HEADER<<- opcode: QUERY, status: NOERROR, id: 64612
-    ... ;; flags: qr rd ra; QUERY: 1, ANSWER: 1, AUTHORITY: 0, ADDITIONAL: 1
-    ...
-    ... ;; OPT PSEUDOSECTION:
-    ... ; EDNS: version: 0, flags:; udp: 4096
-    ... ;; QUESTION SECTION:
-    ... ;example.com.           IN  A
-    ...
-    ... ;; ANSWER SECTION:
-    ... example.com.        29658   IN  A   93.184.216.34
-    ...
-    ... ;; Query time: 52 msec
-    ... ;; SERVER: 2600:1700:bab0:d40::1#53(2600:1700:bab0:d40::1)
-    ... ;; WHEN: Fri Apr 16 16:13:00 PDT 2021
-    ... ;; MSG SIZE  rcvd: 56'''
+    >>> import subprocess
+    >>> import jc.parsers.dig
     >>>
-    >>> jc.parsers.dig.parse(data)
+    >>> cmd_output = subprocess.check_output(['dig', 'example.com'], text=True)
+    >>> data = jc.parsers.dig.parse(cmd_output)
+    >>>
+    >>> data
     [{'id': 64612, 'opcode': 'QUERY', 'status': 'NOERROR', 'flags': ['qr', 'rd', 'ra'], 'query_num': 1, 'answer_num':
     1, 'authority_num': 0, 'additional_num': 1, 'opt_pseudosection': {'edns': {'version': 0, 'flags': [], 'udp':
     4096}}, 'question': {'name': 'example.com.', 'class': 'IN', 'type': 'A'}, 'answer': [{'name': 'example.com.',
@@ -86,4 +73,4 @@ Module Example:
 """
 
 name = 'jc'
-__version__ = '1.16.2'
+__version__ = '1.17.0'
