@@ -13,9 +13,15 @@ Usage (module):
     import jc.parsers.pip_list
     result = jc.parsers.pip_list.parse(pip_list_command_output)
 
-Compatibility:
+Schema:
 
-    'linux', 'darwin', 'cygwin', 'win32', 'aix', 'freebsd'
+    [
+      {
+        "package":     string,
+        "version":     string,
+        "location":    string
+      }
+    ]
 
 Examples:
 
@@ -41,7 +47,8 @@ import jc.parsers.universal
 
 
 class info():
-    version = '1.3'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.4'
     description = '`pip list` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -54,7 +61,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -64,15 +71,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "package":     string,
-            "version":     string,
-            "location":    string
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     # no further processing
     return proc_data
@@ -123,4 +122,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
